# ratser

Quick and dirty library for linear representation of rational series and semigroup trick computation. Includes Walnut import/export.

This is a simple library to manipulate linear representations as described in Walnut book sections 4.10 (Formal series and linear representations) and 4.11 (The semigroup trick).
